@@ -5,18 +5,18 @@ import optparse
 import dm.environment
 from dm.cli.base import CommandLineUtility
 from dm.exceptions import KforgeError, MissingConfigurationPath
+import traceback
 
 class MethodError(object): pass
 
 class AdministrationUtility(CommandLineUtility):
     "Supports command-line system adminstration."
     
-    def __init__(self): #, systemPath=None):
+    def __init__(self):
         CommandLineUtility.__init__(self) # old style class
         self.appInstance = None
         self.interactive = 0
         self.prompt = '> '
-        #self.systemPath = systemPath
 
     def default(self, line):
         print 'Error: Not a valid command: %s' % line
@@ -40,6 +40,12 @@ class AdministrationUtility(CommandLineUtility):
     def buildApplication(self):
         import dm.soleInstance
         self.appInstance = dm.soleInstance.application
+
+    def getApplication(self):
+        # Todo: Rename 'appInstance' attribute as 'application'.
+        if self.appInstance == None:
+            self.buildApplication()
+        return self.appInstance
         
     def convertLineToArgs(self, line):
         unstrippedArgs = line.strip().split()
@@ -83,7 +89,7 @@ Create service from configuration (files, database, Apache config).
         usage = \
 '''migratedump filepath
 
-Dump service object model
+Dump service object model (equals 'db dump')
 '''
         print usage
 
@@ -124,11 +130,14 @@ Dump service filesystem files
 
     def migrateLoad(self, dumpPath):
         self.buildApplication()
-        from dm.migrate import DomainModelLoader
-        dataLoader = DomainModelLoader()
+        dataLoader = self.getDomainModelLoaderClass()()
         dataLoader.loadDataFromFile(dumpPath)
         self.touchMigratedDomainModel()
 
+    def getDomainModelLoaderClass(self):
+        from dm.migrate import DomainModelLoader
+        return DomainModelLoader
+
     def touchMigratedDomainModel(self):
         pass
 
@@ -136,7 +145,7 @@ Dump service filesystem files
         usage = \
 '''migrateload filepath
 
-Load migrated service data
+Load migrated service data (equals 'db init')
 '''
         print usage
 
@@ -201,11 +210,11 @@ Load migrated service data
 '''db <action>
   action = create | delete | init [DUMPFILE] | rebuild | dump DUMPFILE
 
-db create - Creates new database instance using configuration file values.
-db init   - Writes initial system domain data into virgin database instance.
-db delete - Deletes existing database instance using configuration file values.
-db rebuld - Deletes, creates, and then writes the database.
-db dump   - Exports domain data to a (dump) file.
+db create  - Creates new database instance using configuration file values.
+db init    - Writes initial system domain data into virgin database instance.
+db delete  - Deletes existing database instance using configuration file values.
+db rebuild - Deletes, creates, and then writes the database.
+db dump    - Exports domain data to a (dump) file.
 
 NB: If running in interactive mode, a known issue is that due to 
 persisted db connections, once you have run db init or db rebuild
@@ -295,6 +304,7 @@ service configuration file (see 'templates_dir' and 'media_dir').
             try:
                 self.buildApacheConfig()
             except Exception, inst:
+                print traceback.format_exc()
                 msg = "Error: Couldn't generate Apache configuration: %s" % str(inst)
                 print msg
                 return 1
@@ -325,8 +335,7 @@ service configuration file (see 'templates_dir' and 'media_dir').
 
     def buildApacheConfig(self):
         configBuilder = self.createApacheConfigBuilder()
-        configBuilder.buildConfigFile()
-        configBuilder.buildWsgiFile()
+        configBuilder.buildAll()
 
     def reloadApacheConfig(self):
         configBuilder = self.createApacheConfigBuilder()
@@ -421,12 +430,14 @@ class UtilityRunner(object):
 
     usage  = """Usage: %prog [options] [command]"""
 
-    # todo: Resolve having multiple definitions of this variable.
+    # Todo: Resolve having multiple definitions of this variable.
     systemName = 'domainmodel'
     utilityClass = AdministrationUtility
 
     def __init__(self, *args, **kwds):
-        #self.systemPath = ''
+        packageName = self.systemName == 'domainmodel' and 'dm' or self.systemName
+        djangoSettingsModule = '%s.django.settings.main' % packageName
+        os.environ['DJANGO_SETTINGS_MODULE'] = djangoSettingsModule
         self.environment = dm.environment.SystemEnvironment(self.systemName)
         self.configFilePathEnvironVariableName = self.environment.getConfigFilePathEnvironmentVariableName()
         self.createOptionParser()
@@ -444,8 +455,6 @@ class UtilityRunner(object):
                 # Set the environment from the option.
                 configFilePath = os.path.abspath(self.options.configPath)
                 os.environ[self.configFilePathEnvironVariableName] = configFilePath
-            #if self.options.system_path:
-            #    self.systemPath = self.options.system_path
             if self.isScriptRequest():
                 self.runScript()
                 return
@@ -478,7 +487,6 @@ class UtilityRunner(object):
     def createOptionParser(self):
         optionParserClass = optparse.OptionParser
         self.optionParser = optionParserClass(self.usage)
-        #raise Exception, self.optionParser.print_usage()
         
     def createOptionParserOptions(self):
         self.optionParser.add_option(
@@ -510,15 +518,6 @@ class UtilityRunner(object):
             help='Path to service configuration file. Sets ' + \
                  '%s in execution environment' % self.configFilePathEnvironVariableName
         )
-        #self.optionParser.add_option(
-        #    '--system',
-        #    action='store',
-        #    dest='system_path',
-        #    default=None,
-        #    help='If you have installed the system to a path other\n' + \
-        #         ' than the default (sys.prefix) you need to specify\n' + \
-        #         ' the path provided at installation time here.'
-        #)
         self.optionParser.add_option(
             '-c', '--script',
             action='store_true',
@@ -564,9 +563,9 @@ class UtilityRunner(object):
         return errorStatus
 
     def createUtility(self):
-        return self.utilityClass() #self.options.system_path)
+        return self.utilityClass()
 
     def runScript(self):
-        # todo: Generalise implementation in provide.cli.admin
+        # Todo: Generalise implementation in provide.cli.admin.
         pass
 
