@@ -33,7 +33,7 @@ from dm.exceptions import *
 import sqlobject
 sqoVer = None
 isSqoSupported = False
-sqoVers = ['0.7', '0.8', '0.9', '0.10', '0.11', '0.12']
+sqoVers = ['0.7', '0.8', '0.9', '0.10', '0.11', '0.12', '0.13', '0.14', '0.15', '1.0']
 if sqlobject.__doc__ != None:
     sqoDocSplit = sqlobject.__doc__.split(' ')
     if len(sqoDocSplit) > 1:
@@ -130,10 +130,6 @@ class DatabaseFacade(object):
             record = None
             if moddebug:
                 logger.info('Database: Finding %s record in database.' % (className))
-            import os
-            if 'SHIT' in os.environ:
-                if className == 'Role':
-                    raise Exception, "What's the caller?"
             if self.isSelectById(kwds) and len(kwds) == 1:
                 objectId = kwds['id']
                 try:
@@ -486,7 +482,14 @@ class MetaBase(object):
         return self.reservedNames.getReservedNames()
 
     def getSQLStyle(self):
-        return SQLObject.sqlmeta.style
+        # Version < 0.13.
+        if hasattr(SQLObject, 'sqlmeta'):
+            if hasattr(SQLObject.sqlmeta, 'style') and SQLObject.sqlmeta.style:
+                return SQLObject.sqlmeta.style
+        # Version >= 0.13.
+        if hasattr(styles, 'defaultStyle') and styles.defaultStyle:
+             return styles.defaultStyle
+        raise Exception, "Can't find SQLObject's default style object."
             
 
 class MetaMapper(MetaBase):
@@ -497,12 +500,12 @@ class MetaMapper(MetaBase):
         self.isUnique = self.dom.isUnique
         self.isCached = self.dom.isCached
         dbName = self.makeSafeTableName(self.dom.dbName or self.dom.name)
-        if sqoVer in ['0.8', '0.9', '0.10', '0.11', '0.12']:
-            self.domName = dbName
-            self.dbName = dbName
         if sqoVer == '0.7':
             self.domName = self.dom.name
             self.dbName = dbName
+        else:
+            self.domName = dbName
+            self.dbName = dbName
         self.attributeDomNames = {}
         self.attributeDbNames = {}
         self.attributes = []
@@ -603,7 +606,7 @@ class MetaMapperAttribute(MetaBase):
         self.isValueRef = self.dom.isValueRef
         self.isAssociateList = self.dom.isAssociateList
         self.isDomainObjectRef = self.dom.isDomainObjectRef
-        if sqoVer in ['0.8', '0.9', '0.10', '0.11', '0.12'] and self.isDomainObjectRef:
+        if sqoVer in ['0.8', '0.9', '0.10', '0.11', '0.12', '0.13', '0.14', '0.15', '1.0'] and self.isDomainObjectRef:
             self.typeName = self.makeSafeFieldName(self.dom.typeName)
         else:
             self.typeName = self.dom.typeName
@@ -703,7 +706,7 @@ class MetaMapperAttribute(MetaBase):
         elif issubclass(self.dom.__class__, dm.dom.meta.ImageFile):
             return None
         elif issubclass(self.dom.__class__, dm.dom.meta.DomainObjectRef):
-            if sqoVer in ['0.8', '0.9', '0.10', '0.11', '0.12']:
+            if sqoVer in ['0.8', '0.9', '0.10', '0.11', '0.12', '0.13', '0.14', '0.15', '1.0']:
                 dbName = self.dbName
             elif sqoVer in ['0.7']:
                 dbName = self.dbName + 'ID'
@@ -806,8 +809,8 @@ class Mapper(SQLObject):
                     logger.info(msg)
         return self.domainObject()
 
-    def createDomainObject(self):
-        "Reinstantiates pre-recorded domain object."
+#    def createDomainObject(self):
+#        "Reinstantiates pre-recorded domain object."
        
     def getClassName(self):
         return self.__class__.__name__
@@ -822,6 +825,8 @@ class Mapper(SQLObject):
         registry = RequiredFeature('DomainRegistry')
         return registry.getDomainClass(self.getDomainClassName())
 
+    getDomainClass = classmethod(getDomainClass)
+
     def loadDomainObject(self, loadedList, loadMapper=True):
         loadedList.add(self.domainObject())
         if loadMapper:
@@ -908,6 +913,10 @@ class Mapper(SQLObject):
                 mappedValue = getattr(self, dbName)
             else:
                 mappedValue = getattr(self, dbName)
+                # Set empty strings (remedy for bug with SQLite and Python2.7).
+                if mappedValue == None:
+                    if metaAttr.dom.isString:
+                        mappedValue = ''
             setattr(self.domainObject(), domName, mappedValue)
         if moddebug:
             msg = "Database: Done loading %s #%s from mapper attributes." % (
@@ -1061,12 +1070,12 @@ class Mapper(SQLObject):
                 if metaAttr.isDomainObjectRef:
                     mapper = kwds[metaAttr.domName]
                     del kwds[metaAttr.domName]
-                    if sqoVer in ['0.10', '0.11', '0.12']:
+                    if sqoVer in ['0.10', '0.11', '0.12', '0.13', '0.14', '0.15', '1.0']:
                         dbName = metaAttr.dbName
                     elif sqoVer in ['0.7', '0.8', '0.9']:
                         dbName = metaAttr.dbName + 'ID'
                     if mapper:
-                        if sqoVer in ['0.10', '0.11', '0.12']:
+                        if sqoVer in ['0.10', '0.11', '0.12', '0.13', '0.14', '0.15', '1.0']:
                             kwds[dbName] = mapper
                         elif sqoVer in ['0.7', '0.8', '0.9']:
                             kwds[dbName] = mapper.id
@@ -1109,7 +1118,7 @@ class Mapper(SQLObject):
         self.coerceKwds(kwds)
         for name in kwds:
             value = kwds[name]
-            if sqoVer in ['0.10', '0.11', '0.12']:
+            if sqoVer in ['0.10', '0.11', '0.12', '0.13', '0.14', '0.15', '1.0']:
                 if self.meta.attributeDbNames[name].isDomainObjectRef:
                     name += '_id'
             # todo: expand for all database systems
@@ -1156,7 +1165,7 @@ class Mapper(SQLObject):
         sqlEqualsList = []
         for name in kwds:
             value = kwds[name]
-            if sqoVer in ['0.10', '0.11', '0.12']:
+            if sqoVer in ['0.10', '0.11', '0.12', '0.13', '0.14', '0.15', '1.0']:
                 if self.meta.attributeDbNames[name].isDomainObjectRef:
                     name += '_id'
             # todo: expand for all database systems
@@ -1182,7 +1191,7 @@ class Mapper(SQLObject):
         dbType = dictionary[DB_TYPE]
         for name in kwds:
             value = kwds[name]
-            if sqoVer in ['0.10', '0.11', '0.12'] and name != 'id':
+            if sqoVer in ['0.10', '0.11', '0.12', '0.13', '0.14', '0.15', '1.0'] and name != 'id':
                 if self.meta.attributeDbNames[name].isDomainObjectRef:
                     name += '_id'
             if name == 'id':
@@ -1281,7 +1290,7 @@ class Mapper(SQLObject):
                 )
                 sqlEqualsList.append(sqlEquals)
             else:
-                if sqoVer in ['0.10', '0.11', '0.12']:
+                if sqoVer in ['0.10', '0.11', '0.12', '0.13', '0.14', '0.15', '1.0']:
                     if self.meta.attributeDbNames[name].isDomainObjectRef:
                         name += '_id'
                 sqlSafeName = self.makeSqlName(name)
