@@ -68,7 +68,7 @@ class SystemDictionary(dict):
         self[APACHE_PYTHON_MODULE]= 'mod_wsgi'
         self[APACHE_IP_ADDRESS]   = '*'
         self[APACHE_CONFIG_PATH]  = ''
-        self[APACHE_RELOAD_CMD]   = 'sudo /etc/init.d/apache2 graceful'
+        self[APACHE_RELOAD_CMD]   = 'sudo /etc/init.d/apache2 reload'
         self[APACHE_WSGI_REDIRECT_DELAY] = '12'
         self[SKIP_APACHE_RELOAD]  = ''
         self[APACHE_CONFIGTEST_CMD] = '' #'sudo /etc/init.d/apache2 configtest'
