@@ -22,6 +22,9 @@ class TestSystemDictionary(unittest.TestCase):
             imagesPath = self.dictionary[IMAGES_DIR_PATH]
             self.failUnless(os.path.exists(imagesPath), imagesPath)
 
+    def test_systemUserName(self):
+        self.failUnlessEqual(self.dictionary[SYSTEM_USER_NAME], os.environ['USER'])
+
     def test_systemUpSince(self):
         upSince = self.dictionary[SYSTEM_UP_SINCE]
         self.failUnless(upSince)
