@@ -659,11 +659,13 @@ class DomainObject(DomainBase):
                 values[attr.name] = attr.createSortableRepr(self)
         return values
 
-    def asDictValues(self):
-        dictValues = {} 
-        if self.meta:
-            for attr in self.meta.attributes:
-                dictValues[attr.name] = attr.createValueRepr(self)
+    def asDictValues(self, attrNames=None):
+        if attrNames == None:
+            attrNames = self.meta.attributeNames.keys()
+        dictValues = {}
+        for attrName in attrNames:
+            attr = self.meta.attributeNames[attrName]
+            dictValues[attrName] = attr.createValueRepr(self)
         return dictValues
 
     def asDictLabels(self):
