@@ -3,6 +3,7 @@ from dm.dom.testunit import TestCase
 import dm.dom.meta
 from dm.util.datastructure import MultiValueDict
 import datetime
+from dm.dictionarywords import PASSWORD_DIGEST_SECRET
 
 # todo: HasA
 # todo: HasMany
@@ -129,6 +130,10 @@ class TestUrl(MetaAttrTestCase):
     dbValue = 'MyUrl'
     
 
+from dm.messagedigest import *
+from dm.dictionarywords import PASSWORD_DIGEST_SECRET
+import random
+
 class TestPassword(MetaAttrTestCase):
 
     fieldClass = dm.dom.meta.Password
@@ -136,9 +141,17 @@ class TestPassword(MetaAttrTestCase):
     isValueObject = True
     htmlValue = 'MyPassword'
     htmlRepr = ''
-    domValue = '48503dfd58720bd5ff35c102065a52d7'
-    dbValue = '48503dfd58720bd5ff35c102065a52d7'
+    domValue = hmac(key='abcdefgh', msg=md5(htmlValue).hexdigest(), digestmod=sha256).hexdigest()
+    dbValue = domValue
 
+    def setUp(self):
+        super(TestPassword, self).setUp()
+        self.origPasswordDigestSecret = TestCase.dictionary[PASSWORD_DIGEST_SECRET]
+        TestCase.dictionary[PASSWORD_DIGEST_SECRET] = 'abcdefgh'
+
+    def tearDown(self):
+        TestCase.dictionary[PASSWORD_DIGEST_SECRET] = self.origPasswordDigestSecret 
+        super(TestPassword, self).tearDown()
 
 class TestDateTime(MetaAttrTestCase):
     
