@@ -22,9 +22,6 @@ class DomainRegistry(AbstractRegister):
         self.backgroundObjectCache = []
         self.path = ModelPath(self)
 
-    def resolvePathPart(self, pathPart):
-        return getattr(self, pathPart)
-
     def registerDomainClass(self, domainClass):
         self.log.debug("Registering domain class: %s" % domainClass)
         baseClass = DomainObject
@@ -53,7 +50,7 @@ class DomainRegistry(AbstractRegister):
 
         if domainClass.isTemporal==True:
             temporalClassName = self.makeTemporalRevisionClassName(domainClass.meta)
-            domainClass.temporalHistory = HasMany(temporalClassName, 'id', 'parent')
+            domainClass.temporalHistory = HasMany(temporalClassName, 'id', 'parent', isHidden=True)
 
         #
         # 'Concrete Table Inheritance', Martin Fowler
