@@ -45,6 +45,10 @@ class SystemEnvironment(object):
             raise EnvironmentError, message
         return path
         
+    def getSystemUserName(self):
+        "Reads system username from environment variable."
+        return os.environ.get('USER', '')
+        
     def getPythonPath(self):
         "Reads path to system's python library from environment variable."
         return os.environ.get('PYTHONPATH', '')
