@@ -4,6 +4,8 @@
 
 class DomainModelApplicationError(StandardError): pass
 
+class MissingConfigurationPath(DomainModelApplicationError): pass
+
 class ORMError(DomainModelApplicationError): pass
 
 class InvalidSystemDictionary(DomainModelApplicationError): pass
@@ -12,7 +14,7 @@ class AccessControlException(DomainModelApplicationError): pass
 
 class AccessIsAuthorised(AccessControlException): pass
 
-class AccessNotAuthorised(AccessControlException): pass
+class AccessIsForbidden(AccessControlException): pass
 
 class DataMigrationError(DomainModelApplicationError): pass
 
@@ -63,8 +65,10 @@ class KforgePluginMethodNotImplementedError(KforgeAbstractMethodError):
     "Missing plugin method exception class."
     pass
 
-class KforgeMissingPluginSystemClass(KforgeError):
-    "Missing plugin class exception class."
+class MissingPluginSystem(KforgeError):
+    "Missing plugin system exception."
 
+class MultiplePluginSystems(KforgeError):
+    "Multiple plugin system exception."
 
 
