@@ -7,7 +7,7 @@ class FileSystem(object):
     dictionary = RequiredFeature('SystemDictionary')
     logger = RequiredFeature('Logger')
     
-    def getPluginsPath(self, plugin):
+    def getPluginsPath(self):
         if PLUGIN_DIR_PATH in self.dictionary:
             return self.dictionary[PLUGIN_DIR_PATH]
         else:
