@@ -6,7 +6,7 @@ from dm.dictionarywords import DB_MIGRATION_IN_PROGRESS
 from dm.strategy import BaseStrategy
 import os
 import sys
-import simplejson
+from dm.on import json
 
 # Todo: Support for merging data sets (id-fidelity is enforced now).
 # Todo: Add support for comments in plan files!
@@ -37,7 +37,6 @@ class DomainModelDumper(object):
             classData['metaData'] = metaClassData
             # Dumping class register objects
             domainRegister = domainClass.createRegister()
-            #if hasattr(domainRegister, 'getAll'):
             if domainRegister.isStateful:
                 domainRegister = domainRegister.getAll()
             for domainObject in domainRegister:
@@ -54,7 +53,7 @@ class DomainModelDumper(object):
 
     def dumpDataAsJson(self):
         self.dumpData()
-        self.jsonDataDump = simplejson.dumps(self.dataDump)
+        self.jsonDataDump = json.dumps(self.dataDump)
         return self.jsonDataDump
 
     def dumpDataToFile(self, dumpFilePath):
@@ -77,6 +76,7 @@ class DomainModelLoader(object):
         self.dataDump = None
 
     def loadDataFromFile(self, dumpFilePath):
+        # Todo: Wrap file access in try/except block.
         dumpFile = open(dumpFilePath, 'r')
         dumpFileContent = dumpFile.read()
         self.loadDataAsJson(dumpFileContent)
@@ -84,9 +84,9 @@ class DomainModelLoader(object):
     def loadDataAsJson(self, jsonDataDump):
         self.jsonDataDump = jsonDataDump
         try:
-            dumpedData = simplejson.loads(self.jsonDataDump)
+            dumpedData = json.loads(self.jsonDataDump)
         except Exception, inst:
-            msg = "Couldn't parse json string: %s: %s" % (
+            msg = "Couldn't parse JSON string: %s: %s" % (
                 self.jsonDataDump, inst
             )
             raise Exception, msg
@@ -94,6 +94,7 @@ class DomainModelLoader(object):
 
     def loadData(self, dataDump):
         self.dataDump = dataDump
+        self.migrateDataDump()
         self.dictionary.set(DB_MIGRATION_IN_PROGRESS, '1')
         self.identifyReferences(self.dataDump.keys())
         self.determineImportOrder()
@@ -107,6 +108,12 @@ class DomainModelLoader(object):
                 raise Exception("Error: Couldn't find domain classes for: %s" % self.unresolvedClassNames)
         self.dictionary.set(DB_MIGRATION_IN_PROGRESS, '')
 
+    def migrateDataDump(self):
+        pass
+
+    def getDumpVersion(self):
+        return self.dataDump['System']['1']['version']
+
     def identifyReferences(self, classNames):
         "Looks for HasA attrs on classes, collects by referenced class."
         self.unresolvedClassNames = []
@@ -175,7 +182,6 @@ class DomainModelLoader(object):
         for className in self.importOrder:
             classData = self.dataDump[className]
             objectCount = len(classData.keys()) - 1
-            print "Importing %s %s objects." % (objectCount, className)
             domainClass = self.registry.getDomainClass(className)
             classRegister = domainClass.createRegister()
             #del(self.dataDump[className])
@@ -193,6 +199,9 @@ class DomainModelLoader(object):
             #print "Iterating over %s %s" % (className, classDataKeys)
             reflexiveClassData = {}
             freshDomainObjects = {}
+            importCount = 0
+            isCatchingUp = False
+            isLoadingClass = False
             for objectId in classDataKeys:
                 #if objectId == 'metaData':
                 #    continue
@@ -248,16 +257,30 @@ class DomainModelLoader(object):
                             )
                             #print "Warning: %s" % msg
                             raise Exception, msg
+                        elif domainObject.id == objectId or not domainClass.isObjectIdSignificant:
+                            #print "Perfect ID match!"
                             behindWithId = False
+                            #if isCatchingUp:
+                            #    sys.stdout.write('\n')
+                            #    sys.stdout.flush()
+                            #    isCatchingUp = False
+                            #isLoadingClass = True
+                            importCount += 1
+                            sys.stdout.write('\rImporting %s %s objects: %s          ' % (objectCount, className, importCount))
+                            sys.stdout.flush()
                         elif domainObject.id < objectId:
+                            #if isLoadingClass:
+                            #    sys.stdout.write('\n')
+                            #    sys.stdout.flush()
+                            #    isLoadingClass = False
+                            #isCatchingUp = True
+                            sys.stdout.write('\rCatching up with %s object ID %s: %s ' % (className, objectId, domainObject.id))
+                            sys.stdout.flush()
                             sacrificialRecords.append(domainObject)
                             #msg = "Skipping #%s to catch up with index." % (
                             #    domainObject.id
                             #)
                             #print msg
-                        elif domainObject.id == objectId:
-                            #print "Perfect ID match!"
-                            behindWithId = False
                 finally:
                     for domainObject in sacrificialRecords:
                         #print "Dropping sacrificial record: %s" % domainObject
@@ -272,7 +295,6 @@ class DomainModelLoader(object):
                 msg = "Importing %s #%s OK" % (
                     className, objectId
                 )
-                #print msg
 
             reflexiveIds = reflexiveClassData.keys()
             reflexiveIds.sort()
@@ -288,6 +310,10 @@ class DomainModelLoader(object):
                     setattr(domainObject, attrName, refObject)
                     domainObject.save()
 
+            sys.stdout.write("\rImporting %s %s objects: OK                     " % (objectCount, className))
+            sys.stdout.flush()
+            sys.stdout.write('\n')
+            sys.stdout.flush()
             #print "Importing %s objects completed OK." % className
         #print "Imported all domain objects records OK."
 
