@@ -14,10 +14,6 @@ class Database(object):
 
     features = dm.ioc.features
 
-    # name of commands in system dictionary
-    createCommandName = 'db.create_command'
-    deleteCommandName = 'db.delete_command'
-
     def _registerSystemDictionaryFeature(self):
         self.didRegistration = False
         if not 'SystemDictionary' in self.features:
@@ -38,17 +34,18 @@ class Database(object):
     def _runCommand(self, cmd):
         status, output = commands.getstatusoutput(cmd)
         if status:
-            msg = 'Could not execute command\n\t[%s]\n\nReason: %s' \
-                    % (cmd, output)
+            msg = 'Command "%s" failed: %s' % (cmd, output)
             raise(Exception(msg))
 
     def _runCommandFromDictionary(self, commandName):
         self._registerSystemDictionaryFeature()
         self.dictionary = self.features['SystemDictionary']
         cmd = self.dictionary[commandName]
-        # deregister before running command as command may raise exception
-        self._deregisterSystemDictionaryFeature()
-        self._runCommand(cmd)
+        try:
+            self._runCommand(cmd)
+        finally:
+            self._deregisterSystemDictionaryFeature()
+  
 
     def create(self):
         "Create a service database."
@@ -64,15 +61,13 @@ class Database(object):
         """
         try:
             self.delete()
-        except Exception, inst: # allow for non-existence of database
-            msg = \
-'''\nDatabase.rebuild(): error on attempt to delete db. This need *not*
-indicate a problem but simply that the db does not exist. Please check the
-following error message for details:
-    
-%s'''  % inst
-            print(msg)
-        self.create()
+        except Exception, instd:
+            try:
+                self.create()
+            except:
+                raise Exception(instd)
+        else:
+            self.create()
         self.init()
 
     def init(self):
