@@ -172,15 +172,15 @@ class ControlledAccessView(object):
         return False
 
     def authoriseActionObject(self, actionName, protectedObject):
+        person = self.getAuthenticatedPerson()
+        return self.isAuthorised(person=person, actionName=actionName, 
+            protectedObject=protectedObject)
+
+    def getAuthenticatedPerson(self):
+        person = None
         if self.session:
             person = self.session.person
-        else:
-            person = None
-        return self.isAuthorised(
-            person=person,
-            actionName=actionName, 
-            protectedObject=protectedObject
-        )
+        return person
 
     def isAuthorised(self, *args, **kwds):
         return self.accessController.isAuthorised(*args, **kwds)
