@@ -31,7 +31,7 @@ class BaseManipulator(Manipulator):
             self._errors = None
             self.data = data
             self.is_bound = True
-            return self.errors
+            return self._get_errors() # self.errors
         else:
             try:
                 return self.get_validation_errors(data)
@@ -443,7 +443,8 @@ class DomainObjectManipulator(BaseManipulator):
                     self.logger.error("Model: Couldn't undo create: %s" % trace)
                 raise
         except Exception, inst:
-            msg = "System error creating object for data: %s: %s" % (data, repr(inst))
+            trace = traceback.format_exc()
+            msg = "System error creating object for data: %s: %s: %s" % (data, repr(inst), trace)
             self.logger.error(msg)
             self.manipulationErrors = {'': ["System error: %s" % str(inst)]}
         
@@ -529,7 +530,8 @@ class DomainObjectManipulator(BaseManipulator):
             self.setNonAssociateListAttributes()
             self.setAssociateListAttributes()
         except Exception, inst:
-            msg = "System error updating object for data: %s: %s" % (data, repr(inst))
+            trace = traceback.format_exc()
+            msg = "System error updating object for data: %s: %s: %s" % (data, repr(inst), trace)
             self.logger.error(msg)
             self.manipulationErrors = {'': ["System error: %s" % str(inst)]}
 
@@ -583,11 +585,17 @@ class DomainObjectManipulator(BaseManipulator):
         if webkitName == 'django' and webkitVersion == '1.0':
             # Form fields are initialized with these data. 
             self.initial = self.domainObject.asDictValues()
-            # Just in case. :-)
-            return self.initial #domainObject.asRequestParams()
+            return self.initial
         elif webkitName == 'django' and webkitVersion == '0.96':
             return self.domainObject.asRequestParams()
 
+    def getReadableDictValues(self):
+        names = [i.name for i in self.getReadableAttributes()]
+        return self.domainObject.asDictValues(names)
+
+    def getReadableAttributes(self):
+        return [i for i in self.metaObject.attributes if not i.isHidden]
+
 
 class HasManyManipulator(DomainObjectManipulator):
     "Domain object 'HasMany' attribute manipulator."
