@@ -20,6 +20,8 @@ elif webkitName == 'django':
         from django.utils.html import escape as htmlescape
         from django.http import HttpRequest
         from django.http import HttpResponse
+        from django.http import HttpResponseBadRequest
+        from django.http import HttpResponseNotFound
         from django.http import HttpResponseRedirect
         from django.template import Context
         if webkitVersionFull[1] >= 2:
